#include <stdio.h>
#include <asm/io.h>

#define LINUXBOT 1
#include "robot.c"

#define STOPTIME 100000		/* wait time after stopping for an obstacle */
#define REVSPEED 0.2		/* slow reverse speed */
#define REVTIME  500000		/* slow reverse time */
#define SPINSPEED 0.3		/* spin speed */
#define SPINTIME 300000		/* spin time */
#define AHEADSPEED 0.5		/* full ahead speed */

robot Bot;

/* Avoid program - modified for closed loop motor control
   on the LinuxBot, AW  13/9/00 */

void AllStop( void )
{
	velMove( &Bot, 0.0 , 0.0 );
	usleep( STOPTIME );
}

void SlowReverse( void )
{
	velMove( &Bot, -REVSPEED, -REVSPEED );
	usleep( REVTIME );
}

void RandomSpin( void )
{
	/* this is not random, yet */
	velMove( &Bot, SPINSPEED, -SPINSPEED );
	usleep( SPINTIME );
}

void ClockwiseSpin( void )
{
	velMove( &Bot, -SPINSPEED, SPINSPEED );
	usleep( SPINTIME );
}

void AntiClockSpin( void )
{
	velMove( &Bot, SPINSPEED, -SPINSPEED );
	usleep( SPINTIME );
}

int main( void )
{
	unsigned char status;
	
	/* request access to the motor drive ports.. */
	if ( !accessPorts() )
	{
		printf("Port access denied..  root privileges needed\n");
		exit(1);
	}

	resetBot( &Bot );
	setMode( &Bot, IV_MODE );	

	/* Loop forever.. */
	while(1)
	{
		status = getSensors(); 	/* read IR sensor bits */
		setLEDs( ~status & 3 );	/* echo on LEDs */
		if ( status == 0 )
		{
			/* both sensors are ON */
			AllStop();
			SlowReverse();
			RandomSpin();
		}
		else if ( status == 1 )
		{
			/* right sensor is ON */  
			AllStop();
			AntiClockSpin();
		}
		else if ( status == 2 )
		{
			/* left sensor is ON */ 
			AllStop();
			ClockwiseSpin();
		}
		/* else neither sensor is on, ie clear ahead */

		velMove( &Bot, AHEADSPEED, AHEADSPEED );
		usleep( 50000 );			/* sleep for 50mS */
	}
}
